<template>
	<div class="section-main-container layout-padding">
		<div class="section-main-padding layout-padding-auto layout-padding-view">
			<div class="section-user-search mb15">
				<el-form :inline="true" :model="state.tableData.param" class="demo-form-inline" label-position="left"
					size="default" @submit.prevent>
					<el-form-item label="人员姓名">
						<el-input v-model="state.tableData.param.name" placeholder="请输入人员姓名" clearable @keyup.enter="getTableData"
							style="max-width: 180px" />
					</el-form-item>
					<el-form-item label="公司名称">
						<el-input v-model="state.tableData.param.companyName" placeholder="请输入公司名称" clearable
							@keyup.enter="getTableData" style="max-width: 180px" />
					</el-form-item>
					<el-form-item label="驻勤点名称">
						<el-input v-model="state.tableData.param.securityStationName" placeholder="请输入驻勤点名称" clearable
							@keyup.enter="getTableData" style="max-width: 180px" />
					</el-form-item>

					<el-form-item label="监管机构">
						<!-- <el-select v-model="state.tableData.param.superviseDepartId" placeholder="请选择" style="width: 100%;">
							<el-option label="" value="" />
						</el-select> -->
						<el-cascader v-model="state.tableData.param.superviseDepartIdArr" :options="state.tableData.param.options"
							:props="customProps" collapse-tags collapse-tags-tooltip :show-all-levels="false" clearable
							ref="myCascader" />
					</el-form-item>

					<el-form-item label="证件号">
						<el-input v-model="state.tableData.param.idCardNo" placeholder="请输入人员身份证号" clearable
							@keyup.enter="getTableData" style="max-width: 180px" />
					</el-form-item>

					<el-form-item label="时间">
						<el-date-picker v-model="state.tableData.param.createdStarEndDate" type="daterange" range-separator="-"
							start-placeholder="开始时间" end-placeholder="结束时间" format="YYYY-MM-DD HH:mm:ss"  value-format="YYYY-MM-DD HH:mm:ss" />
					</el-form-item>

					<el-form-item label="持证情况">
						<el-select v-model="state.tableData.param.hasSecurityCertificateNo" placeholder="请选择" clearable style="width: 100%;">
							<el-option label="已持证" :value="true" />
							<el-option label="未持证" :value="false" />
						</el-select>
					</el-form-item>

					<el-form-item label="操作类型">
						<el-select v-model="state.tableData.param.recordStatuses"  placeholder="请选择" clearable  style="width: 100%;">
						    <el-option label="签到" value="SignIn" />
							<el-option label="签退" value="SignOut" />
						</el-select>
					</el-form-item>


					<el-form-item>
						<el-button type="primary" @click="getTableData">查询</el-button>
						<el-button type="default" @click="resetgetTableData">重置</el-button>
						<el-button type="primary" @click="exportData">导出</el-button>
						<el-button type="primary" @click="exportDataDetail">导出明细</el-button>
					</el-form-item>
				</el-form>

			</div>
			<el-table :data="state.tableData.data" v-loading="state.tableData.loading" style="width: 100%">
				<el-table-column label="序号" width="60">
					<template #default="scope">
						{{ scope.$index + 1 + (state.tableData.param.pageIndex - 1) * state.tableData.param.pageSize }}
					</template>
				</el-table-column>
			
				<el-table-column prop="name" label="姓名" width="80" show-overflow-tooltip></el-table-column>
				<el-table-column prop="idCard" label="身份证号" width="230">
					<template #default="scope">
						<span class="idCarNoSpan"><em>{{
							scope.row.showidCardNo ? scope.row.idCard : scope.row.idCard.replace(/^(.{3})(?:\d+)(.{4})$/,
								"$1******$2")
						}}</em><el-button link type="primary" size="small" @click="idCardNoBtn(scope.row)">{{
	scope.row.showidCardNo ? '隐藏' : '显示' }}</el-button></span>
					</template>
				</el-table-column>
				<el-table-column prop="securityCertificateNoStatus" label="持证情况" width="120" show-overflow-tooltip></el-table-column>
				<el-table-column prop="companyName" label="公司名称" show-overflow-tooltip></el-table-column>
				<el-table-column prop="dutyStatusText" label="操作类型"  show-overflow-tooltip></el-table-column>
				<el-table-column prop="countOfDutyStatus" label="操作次数" show-overflow-tooltip>
					<template #default="scope">
					    <span>
							<el-link type="primary" @click.prevent="onOpenDetail('edit', scope.row)">{{ scope.row.countOfDutyStatus}}</el-link>
						</span>
					</template>
				</el-table-column>


			</el-table>
			<el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" class="mt15"
				:pager-count="5" :page-sizes="[10, 20, 30, 100, 200, 300, 1000]"
				v-model:current-page="state.tableData.param.pageIndex" background
				v-model:page-size="state.tableData.param.pageSize" layout="total, sizes, prev, pager, next, jumper"
				:total="state.tableData.total">
			</el-pagination>
		</div>
		<ConfigDialog :platform="props.platform" ref="configDialogRef" @refresh="getTableData()" />
	</div>
</template>

<script setup lang="ts" name="signedManage">
import { defineAsyncComponent, reactive, onMounted, ref, toRaw, defineProps } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import { ConfigApi } from '/@/api/api'
import { useRoute, useRouter, onBeforeRouteUpdate } from 'vue-router';
import { refreshBtnView } from '/@/components/refreshView';

const props = defineProps({
    platform: {
        type: String,
        required: true
    },
});
// 引入组件
const ConfigDialog = defineAsyncComponent(() => import('./commandDialog.vue'));
// 定义变量内容
const customProps = {
	multiple: true,// 启用多选
	checkStrictly: false,//父子节点不互相关联
	emitPath: true,//若设置 false，则只返回该节点的值
	value: 'code',//自定义当前数组的键名 - value
	label: 'name', // 自定义当前数组的键名 - label 
}


const route = useRoute()
const configDialogRef = ref();
const myCascader = ref();
const state = reactive({
	tableData: {
		data: [],
		total: 0,
		loading: false,
		param: {
			pageIndex: 1,
			pageSize: 10,
			forExport:true,
			name: '',
			companyName: '',
			securityStationName: '',
			superviseDepartIds: [],
			superviseDepartIdArr: [],
			idCardNo: '',
			createdStarEndDate: [] as string[],
			createdStarDate: '',
			createdEndDate: '',
			options: [],
			hasSecurityCertificateNo:null,
			recordStatuses:null,
		},
	},
	RestestcreatedStarEndDate: [] as string[],
	RestestcreatedStarDate: '',
	RestestcreatedEndDate: '',
});
//查询监管机构
const searchDeparts = () => {
	ConfigApi().searchDepartsApi({deskTypes: props.platform==='2' ? ['Proprietor'] : props.platform==='3' ? ["TemporarySecurity"] : ['Normal']}).then(response => {
		console.log('response查询00', response)
		console.log('response.data00', response.data)
		if (response.status == 200) {
			let data = response.data;
			console.log(data)
			state.tableData.param.options = data;
			// state.tableData.data = response.data.data
			// state.tableData.total = response.data.totalCount;
		}
	})
}
// 初始化表格数据
const getTableData = () => {
	// debugger
	console.log(state.tableData.param.superviseDepartIdArr)
	let Depstr: [] = [];
	if (myCascader.value.getCheckedNodes().length) {
		myCascader.value.getCheckedNodes().forEach(item => Depstr.push(item.value))
	}
	state.tableData.param.superviseDepartIds = Depstr
	state.tableData.loading = true;
	let obj = state.tableData.param
	if (obj.createdStarEndDate) {
		obj.createdStarDate = obj.createdStarEndDate[0]
		obj.createdEndDate = obj.createdStarEndDate[1]
	}
	let obj2 = JSON.parse(JSON.stringify(obj))
	delete obj2.options
	delete obj2.superviseDepartIdArr
	delete obj2.createdStarEndDate
	obj2.hasSecurityCertificateNo=obj2.hasSecurityCertificateNo===null||obj2.hasSecurityCertificateNo===''?null:obj2.hasSecurityCertificateNo
	obj2.recordStatuses=obj2.recordStatuses?[obj2.recordStatuses]:[]
	obj2.deskTypes = props.platform==='2' ? ['Proprietor'] : props.platform==='3' ? ["TemporarySecurity"] : ['Normal']
    obj2.forExport = false
	ConfigApi().attendanceSearchApi(obj2).then(response => {
		console.log('response查询11', response)
		console.log('response.data', response.data)
		if (response.status == 200) {
			state.tableData.data = response.data.data
			state.tableData.total = response.data.totalCount;
			state.tableData.data.forEach((item) => {
				item.showidCardNo = false
			})
		}
	})
	setTimeout(() => {
		state.tableData.loading = false;
	}, 500);
};
const resetgetTableData = () => {
	if (myCascader.value.getCheckedNodes().length) {
		myCascader.value.$refs.panel.clearCheckedNodes()//重置el-cascader
	}
	let obj = {
		pageIndex: 1,
		pageSize: 10,
		forExport:true,
		name: '',
		companyName: '',
		securityStationName: '',
		superviseDepartIds: [],
		superviseDepartIdArr: [],
		idCardNo: '',
		createdStarEndDate: state.RestestcreatedStarEndDate,
		createdStarDate: state.RestestcreatedStarDate,
		createdEndDate: state.RestestcreatedEndDate,
		options: state.tableData.param.options,
		hasSecurityCertificateNo:null,
		recordStatuses:null,
	}
	state.tableData.param = reactive(obj)
	getTableData()
};
// 分页改变
const onHandleSizeChange = (val: number) => {
	state.tableData.param.pageSize = val;
	getTableData();
};
// 分页改变
const onHandleCurrentChange = (val: number) => {
	state.tableData.param.pageIndex = val;
	getTableData();
};
//刷新当前列表
// const reload = inject('reload')//子接收
const refreshBtn = () => {
	refreshBtnView(route)
}
//显示隐藏身份证号
const idCardNoBtn = (row) => {
	console.log(row)
	row.showidCardNo = !row.showidCardNo
}
//导出excel
const exportData = () => {
	let Depstr: [] = [];
	if (myCascader.value.getCheckedNodes().length) {
		myCascader.value.getCheckedNodes().forEach(item => Depstr.push(item.value))
	}
	state.tableData.param.superviseDepartIds = Depstr
	let obj = JSON.parse(JSON.stringify(state.tableData.param))
	if (obj.createdStarEndDate) {
		obj.createdStarDate = (obj.createdStarEndDate)[0]
		obj.createdEndDate = (obj.createdStarEndDate)[1]
	} else {
		ElMessage.error('请选择日期');
		return
	}
	obj.hasSecurityCertificateNo=obj.hasSecurityCertificateNo===null||obj.hasSecurityCertificateNo===''?null:obj.hasSecurityCertificateNo
	obj.recordStatuses=obj.recordStatuses?[obj.recordStatuses]:[]
	delete obj.options
	delete obj.superviseDepartIdArr
	delete obj.createdStarEndDate
	delete obj.pageIndex
	delete obj.pageSize
	obj.deskTypes = props.platform==='2' ? ['Proprietor'] : props.platform==='3' ? ["TemporarySecurity"] : ['Normal']
	
	state.tableData.loading = true;
	ConfigApi().exportsignedManageApi(obj).then(response => {
		setTimeout(() => {
			state.tableData.loading = false;
			getTableData()
		}, 500);
		const content = response;
		const blob = new Blob([content]);
		const fileName = `签到管理.xlsx`;
		if ("download" in document.createElement("a")) {
			// 非IE下载
			const elink = document.createElement("a");
			elink.download = fileName;
			elink.style.display = "none";
			elink.href = URL.createObjectURL(blob);
			document.body.appendChild(elink);
			elink.click();
			URL.revokeObjectURL(elink.href); // 释放URL 对象
			document.body.removeChild(elink);
		} else {
			// IE10+下载
			navigator.msSaveBlob(blob, fileName);
		}
	}).catch((error) => { })
}
const exportDataDetail = () => {
	let Depstr: [] = [];
	if (myCascader.value.getCheckedNodes().length) {
		myCascader.value.getCheckedNodes().forEach(item => Depstr.push(item.value))
	}
	state.tableData.param.superviseDepartIds = Depstr
	let obj = JSON.parse(JSON.stringify(state.tableData.param))
	if (obj.createdStarEndDate) {
		obj.createdStarDate = (obj.createdStarEndDate)[0]
		obj.createdEndDate = (obj.createdStarEndDate)[1]
	} else {
		ElMessage.error('请选择日期');
		return
	}
	obj.hasSecurityCertificateNo=obj.hasSecurityCertificateNo===null||obj.hasSecurityCertificateNo===''?null:obj.hasSecurityCertificateNo
	obj.recordStatuses=obj.recordStatuses?[obj.recordStatuses]:[]
	delete obj.options
	delete obj.superviseDepartIdArr
	delete obj.createdStarEndDate
	delete obj.pageIndex
	delete obj.pageSize
	obj.deskTypes = props.platform==='2' ? ['Proprietor'] : props.platform==='3' ? ["TemporarySecurity"] : ['Normal']
	
	state.tableData.loading = true;
	ConfigApi().exportDetailsignedManageApi(obj).then(response => {
		setTimeout(() => {
			state.tableData.loading = false;
			getTableData()
		}, 500);
		const content = response;
		const blob = new Blob([content]);
		const fileName = `签到管理明细.xlsx`;
		if ("download" in document.createElement("a")) {
			// 非IE下载
			const elink = document.createElement("a");
			elink.download = fileName;
			elink.style.display = "none";
			elink.href = URL.createObjectURL(blob);
			document.body.appendChild(elink);
			elink.click();
			URL.revokeObjectURL(elink.href); // 释放URL 对象
			document.body.removeChild(elink);
		} else {
			// IE10+下载
			navigator.msSaveBlob(blob, fileName);
		}
	}).catch((error) => { })
}
//详情
const onOpenDetail=(type:string,row:object)=>{
	 console.log(type)
	 console.log(row)
	 configDialogRef?.value.openDialog(type, row,state.tableData.param);
}
// 页面加载时
onMounted(() => {
	var tempDate = new Date() // 获取今天的日期
	let nowDate = tempDate.getFullYear() + '-' + (tempDate.getMonth() + 1 < 10 ? '0' + (tempDate.getMonth() + 1) : tempDate.getMonth() + 1) + '-' + (tempDate.getDate() < 10 ? '0' + tempDate.getDate() : tempDate.getDate())
	tempDate.setDate(tempDate.getDate() - 6) // 今天的前N天的日期，N自定义
	var endDate = tempDate.getFullYear() + '-' + (tempDate.getMonth() + 1 < 10 ? '0' + (tempDate.getMonth() + 1) : tempDate.getMonth() + 1) + '-' + (tempDate.getDate() < 10 ? '0' + tempDate.getDate() : tempDate.getDate())
	console.log('endDate', endDate)

	nowDate=nowDate +' 00:00:00'
	endDate=endDate +' 00:00:00'

	state.RestestcreatedStarEndDate = ['' + endDate + '', '' + nowDate + '']
	state.RestestcreatedStarDate = [endDate]
	state.RestestcreatedEndDate = [nowDate]

	state.tableData.param.createdStarEndDate = ['' + endDate + '', '' + nowDate + '']//获取当前日期与前6天日期['2023-03-24','2023-03-30']
	searchDeparts();//查询监管机构
	// getTableData();
});
</script>

<style scoped lang="scss">
.section-main-container {
	.section-main-padding {
		padding: 15px;

		.el-table {
			flex: 1;
		}

	}

	.idCarNoSpan {
		display: flex;

		em {
			font-style: normal;
			margin-right: 20px;
		}
	}
}
</style>
